@@ -22,7 +22,7 @@
 %                                March 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -120,17 +120,14 @@ WandExport WandView *CloneWandView(const WandView *wand_view)
   WandView
     *clone_view;
 
-  register ssize_t
+  ssize_t
     i;
 
   assert(wand_view != (WandView *) NULL);
   assert(wand_view->signature == WandSignature);
   if (wand_view->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand_view->name);
-  clone_view=(WandView *) AcquireMagickMemory(sizeof(*clone_view));
-  if (clone_view == (WandView *) NULL)
-    ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      wand_view->name);
+  clone_view=(WandView *) AcquireCriticalMemory(sizeof(*clone_view));
   (void) memset(clone_view,0,sizeof(*clone_view));
   clone_view->id=AcquireWandId();
   (void) FormatLocaleString(clone_view->name,MaxTextExtent,"%s-%.20g",
@@ -174,10 +171,10 @@ WandExport WandView *CloneWandView(const WandView *wand_view)
 %
 */
 
-static PixelWand ***DestroyPixelsThreadSet(PixelWand ***pixel_wands,
+static PixelWand ***DestroyPixelsTLS(PixelWand ***pixel_wands,
   const size_t number_wands,const size_t number_threads)
 {
-  register ssize_t
+  ssize_t
     i;
 
   assert(pixel_wands != (PixelWand ***) NULL);
@@ -192,7 +189,7 @@ WandExport WandView *DestroyWandView(WandView *wand_view)
 {
   assert(wand_view != (WandView *) NULL);
   assert(wand_view->signature == WandSignature);
-  wand_view->pixel_wands=DestroyPixelsThreadSet(wand_view->pixel_wands,
+  wand_view->pixel_wands=DestroyPixelsTLS(wand_view->pixel_wands,
     wand_view->extent.width,wand_view->number_threads);
   wand_view->view=DestroyCacheView(wand_view->view);
   wand_view->exception=DestroyExceptionInfo(wand_view->exception);
@@ -304,21 +301,21 @@ WandExport MagickBooleanType DuplexTransferWandViewIterator(WandView *source,
     MagickBooleanType
       sync;
 
-    register const IndexPacket
+    const IndexPacket
       *magick_restrict duplex_indexes,
       *magick_restrict indexes;
 
-    register const PixelPacket
+    const PixelPacket
       *magick_restrict duplex_pixels,
       *magick_restrict pixels;
 
-    register IndexPacket
+    IndexPacket
       *magick_restrict destination_indexes;
 
-    register ssize_t
+    ssize_t
       x;
 
-    register PixelPacket
+    PixelPacket
       *magick_restrict destination_pixels;
 
     if (status == MagickFalse)
@@ -580,13 +577,13 @@ WandExport MagickBooleanType GetWandViewIterator(WandView *source,
     const int
       id = GetOpenMPThreadId();
 
-    register const IndexPacket
+    const IndexPacket
       *indexes;
 
-    register const PixelPacket
+    const PixelPacket
       *pixels;
 
-    register ssize_t
+    ssize_t
       x;
 
     if (status == MagickFalse)
@@ -752,13 +749,13 @@ WandExport MagickBooleanType IsWandView(const WandView *wand_view)
 %
 */
 
-static PixelWand ***AcquirePixelsThreadSet(const size_t number_wands,
+static PixelWand ***AcquirePixelsTLS(const size_t number_wands,
   const size_t number_threads)
 {
   PixelWand
     ***pixel_wands;
 
-  register ssize_t
+  ssize_t
     i;
 
   pixel_wands=(PixelWand ***) AcquireQuantumMemory(number_threads,
@@ -770,7 +767,7 @@ static PixelWand ***AcquirePixelsThreadSet(const size_t number_wands,
   {
     pixel_wands[i]=NewPixelWands(number_wands);
     if (pixel_wands[i] == (PixelWand **) NULL)
-      return(DestroyPixelsThreadSet(pixel_wands,number_wands,number_threads));
+      return(DestroyPixelsTLS(pixel_wands,number_wands,number_threads));
   }
   return(pixel_wands);
 }
@@ -782,10 +779,7 @@ WandExport WandView *NewWandView(MagickWand *wand)
 
   assert(wand != (MagickWand *) NULL);
   assert(wand->signature == WandSignature);
-  wand_view=(WandView *) AcquireMagickMemory(sizeof(*wand_view));
-  if (wand_view == (WandView *) NULL)
-    ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      GetExceptionMessage(errno));
+  wand_view=(WandView *) AcquireCriticalMemory(sizeof(*wand_view));
   (void) memset(wand_view,0,sizeof(*wand_view));
   wand_view->id=AcquireWandId();
   (void) FormatLocaleString(wand_view->name,MaxTextExtent,"%s-%.20g",
@@ -798,7 +792,7 @@ WandExport WandView *NewWandView(MagickWand *wand)
   wand_view->extent.width=wand->images->columns;
   wand_view->extent.height=wand->images->rows;
   wand_view->number_threads=GetOpenMPMaximumThreads();
-  wand_view->pixel_wands=AcquirePixelsThreadSet(wand_view->extent.width,
+  wand_view->pixel_wands=AcquirePixelsTLS(wand_view->extent.width,
     wand_view->number_threads);
   if (wand_view->pixel_wands == (PixelWand ***) NULL)
     ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
@@ -843,10 +837,7 @@ WandExport WandView *NewWandViewExtent(MagickWand *wand,const ssize_t x,
 
   assert(wand != (MagickWand *) NULL);
   assert(wand->signature == WandSignature);
-  wand_view=(WandView *) AcquireMagickMemory(sizeof(*wand_view));
-  if (wand_view == (WandView *) NULL)
-    ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      GetExceptionMessage(errno));
+  wand_view=(WandView *) AcquireCriticalMemory(sizeof(*wand_view));
   (void) memset(wand_view,0,sizeof(*wand_view));
   wand_view->id=AcquireWandId();
   (void) FormatLocaleString(wand_view->name,MaxTextExtent,"%s-%.20g",
@@ -861,7 +852,7 @@ WandExport WandView *NewWandViewExtent(MagickWand *wand,const ssize_t x,
   wand_view->extent.x=x;
   wand_view->extent.y=y;
   wand_view->number_threads=GetOpenMPMaximumThreads();
-  wand_view->pixel_wands=AcquirePixelsThreadSet(wand_view->extent.width,
+  wand_view->pixel_wands=AcquirePixelsTLS(wand_view->extent.width,
     wand_view->number_threads);
   if (wand_view->pixel_wands == (PixelWand ***) NULL)
     ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
@@ -917,7 +908,7 @@ MagickExport void SetWandViewDescription(WandView *wand_view,
 %  SetWandViewIterator() iterates over the wand view in parallel and calls
 %  your set method for each scanline of the view.  The pixel extent is
 %  confined to the image canvas-- that is no negative offsets or widths or
-%  heights that exceed the image dimension.  The pixels are initiallly
+%  heights that exceed the image dimension.  The pixels are initially
 %  undefined and any settings you make in the callback method are automagically
 %  synced back to your image.
 %
@@ -993,13 +984,13 @@ WandExport MagickBooleanType SetWandViewIterator(WandView *destination,
     MagickBooleanType
       sync;
 
-    register IndexPacket
+    IndexPacket
       *magick_restrict indexes;
 
-    register ssize_t
+    ssize_t
       x;
 
-    register PixelPacket
+    PixelPacket
       *magick_restrict pixels;
 
     if (status == MagickFalse)
@@ -1178,19 +1169,19 @@ WandExport MagickBooleanType TransferWandViewIterator(WandView *source,
     MagickBooleanType
       sync;
 
-    register const IndexPacket
+    const IndexPacket
       *magick_restrict indexes;
 
-    register const PixelPacket
+    const PixelPacket
       *magick_restrict pixels;
 
-    register IndexPacket
+    IndexPacket
       *magick_restrict destination_indexes;
 
-    register ssize_t
+    ssize_t
       x;
 
-    register PixelPacket
+    PixelPacket
       *magick_restrict destination_pixels;
 
     if (status == MagickFalse)
@@ -1351,13 +1342,13 @@ WandExport MagickBooleanType UpdateWandViewIterator(WandView *source,
     const int
       id = GetOpenMPThreadId();
 
-    register IndexPacket
+    IndexPacket
       *magick_restrict indexes;
 
-    register ssize_t
+    ssize_t
       x;
 
-    register PixelPacket
+    PixelPacket
       *magick_restrict pixels;
 
     if (status == MagickFalse)
